;;; Linux-Mandrake Configuration for XEmacs
; Chmouel Boudjnah <chmouel@mandrakesoft.com>
; Pixel <pixel@mandrakesoft.com>
; Frederic Lepied <flepied@mandrakesoft.com>

;; Macros to detect if we are under X.
(defmacro Xlaunch (&rest x) (list 'if (eq window-system 'x)(cons 'progn x)))

; Under X to get the suppr key working.
(Xlaunch (define-key global-map [(delete)] "\C-d"))

;;; XEmacs compatibility
(global-set-key [(control tab)] `other-window)
(global-set-key [(meta g)] `goto-line)
(defun switch-to-other-buffer () (interactive) (switch-to-buffer (other-buffer)))
(global-set-key [(meta control ?l)] `switch-to-other-buffer)
(global-set-key [(meta O) ?H] 'beginning-of-line)
(global-set-key [(meta O) ?F] 'end-of-line)

; Don't add lines on the end of lines unless we want.
(setq next-line-add-newlines nil)

; Shift-arrows a la windows...
(custom-set-variables
 '(pc-select-meta-moves-sexps t)
 '(pc-select-selection-keys-only t)
 '(pc-selection-mode t nil (pc-select)))

;; By default we starting in text mode.
(setq initial-major-mode (lambda () (text-mode) (turn-on-auto-fill) (font-lock-mode)))

; Don't ask to revert for TAGS
(setq revert-without-query (cons "TAGS" revert-without-query))

;; Use the following for i18n
;(standard-display-european t)
;(set-language-environment "latin-1")

;; Color and Fonts.
(require 'font-lock)
(setq font-lock-mode-maximum-decoration t)
(Xlaunch (set-face-font 'default "-*-Fixed-Medium-R-*-*-*-130-*-*-*-*-iso8859-1"))

;; turn on colorization.
(Xlaunch(if (fboundp 'global-font-lock-mode)(global-font-lock-mode t)))

; Turn on selection and change the default color
(setq transient-mark-mode 't highlight-nonselected-windows 't)

;; Locales variables adapted from Debian.el for Linux-Mandrake.
(setq Info-directory-list
      '("/usr/info/" "/usr/share/info" "/usr/local/info" "/usr/info/xemacs"
        "/usr/lib/xemacs/packages/info"
        "/usr/lib/xemacs/mule-packages/info"
        "/usr/lib/xemacs/site-packages/info"))

(setq Info-additional-search-directory-list
      '("/usr/info/xemacs"))

(setq news-path "/var/spool/news")

(custom-set-variables ;; '(nnmail-spool-file "/var/spool/mail/$user")
                      '(gnuserv-program 
                          (concat exec-directory "/gnuserv")))

(defun dir-and-all-good-subs (this-directory)
  "Returns list of argument and all subdirectories of argument not
starting with a '.'"
  (if (file-exists-p this-directory)
      (append (list (expand-file-name this-directory))
              (mapcar '(lambda (dir-string)
                         (concat dir-string "/")) 
                      (directory-files 
                       (expand-file-name this-directory) 
                       t "^[^\\.]" nil 1)))
    nil))

(setq load-path
      (let* ((point
              (string-match "[0-9]*\.[0-9]*.*XEmacs.*"
                            emacs-version))
             (xemacs-maj-version
              (substring emacs-version point (+ point 2)))
             (xemacs-version
              (substring emacs-version point (+ point 5))))
        (append
         `(,@(dir-and-all-good-subs "/usr/local/lib/xemacs/site-lisp")
             ,@(dir-and-all-good-subs "/usr/lib/xemacs/mule-packages/lisp/")
             ,@(dir-and-all-good-subs "/usr/lib/xemacs/site-packages/lisp/")
	     ,@(dir-and-all-good-subs "/usr/lib/xemacs/xemacs-packages/lisp/")
             ,@(dir-and-all-good-subs (concat "/usr/lib/xemacs-" xemacs-version "/lisp/")))
         load-path
         ;;,@(dir-and-all-good-subs
         ;; (concat "/usr/share/xemacs-" xemacs-version "/lisp/"))
         '("/usr/share/emacs/site-lisp"))))


;; Local Variables:
;; mode: emacs-lisp
;; End:
